Json

Struct Json 

pub struct Json<T>(pub T);
JSON request body extractor and response, whose failures are JSON too.

As an extractor it requires Content-Type: application/json; unlike axum::Json, a body that is missing that header or is not valid JSON for T is answered with a JSON 400 (ApiError with Error::BadRequest carrying axum’s explanation). As a response it serializes T with status 200 and Content-Type: application/json.

Examples

use axum::{http::StatusCode, response::IntoResponse};
use ocre::Json;

let response = Json(serde_json::json!({"id": 1})).into_response();
assert_eq!(response.status(), StatusCode::OK);
assert_eq!(response.headers()["content-type"], "application/json");

In a handler:

use ocre::{ApiResult, Json};
use serde::{Deserialize, Serialize};

#[derive(Deserialize, Serialize)]
struct Echo {
    message: String,
}

async fn echo(Json(body): Json<Echo>) -> ApiResult<Json<Echo>> {
    Ok(Json(body))
}

Tuple Fields

0: T